@@ -508,6 +508,22 @@ class CloudPods:
             log.error(f"Failed to request /servers: Error.\rerr msg is {str(e)}", exc_info=True)
             return None
 
+    @enter_and_leave_function
+    def wait_for_server_is_deleted(self,server_id):
+        try:
+            for i in range(60):
+                server_detail = self.get_server_detail(server_id)
+                if server_detail is None:
+                    log.info(f"server_id: {server_id} deleted")
+                    return True
+                log.warn(f"server_id: {server_id} is deleting")
+                time.sleep(5)
+            log.warn(f"Failed to wait for server {server_id} is deleted: Error.\nserver_detail is {server_detail}")
+            return False
+        except Exception as e:
+            log.error(f"Failed to wait for server {server_id} is deleted: Error.\rerr msg is {str(e)}",exc_info=True)
+            return False
+
     @enter_and_leave_function
     def delete_server(self, server_id):
         try:
@@ -535,6 +551,8 @@ if __name__ == '__main__':
     cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
     # rs=cloudpods.get_baremetal_hosts()
     # print(rs)
+    rs=cloudpods.get_server_detail("8c925c8e-752f-4358-8c3e-a80847732d91")
+    print(rs)
     # print(len(rs["hosts"]))
     # rs=cloudpods.get_baremetal_servers()
     # print(rs)
@@ -545,8 +563,8 @@ if __name__ == '__main__':
     # print(rs)
     # rs=cloudpods.host_has_baremetal_server("701f77bf-8cac-4b20-8787-41dc3ddc3f77")
     # print(rs)
-    rs=cloudpods.get_host_spec("6ff06f38-5806-4d6f-8ad4-d2cf769392fa")
-    print(rs)
+    # rs=cloudpods.get_host_spec("6ff06f38-5806-4d6f-8ad4-d2cf769392fa")
+    # print(rs)
     # rs=cloudpods.create_server_by_guest_image("ab370e36-6fd2-49b8-8cbe-d6af6a03d3b2","b193a66d-be6f-49c0-8c19-df43333856db",
     #                                           "x86_64",20480,[20],["7ff50bd9-8fbd-4c57-8687-e47933419214"],"demo",hypervisor="baremetal",bios="UEFI",
     #                                           storage_type="ssd",
